@@ -1,5 +1,5 @@
 #' Add stage names to matrices
-#' 
+#'
 #' Adds user-supplied or automatically-generated stage names to a matrix
 #' population model (MPM).
 #'
@@ -13,18 +13,20 @@
 #'   For example, stage \code{1} becomes \code{01} for matrices with 10-99
 #'   stages, \code{001} for matrices with 100-999 stages, and so on. Defaults to
 #'   \code{TRUE}.
-#'   
+#'
 #' @author William K. Petry <wpetry@@ncsu.edu>
-#' 
+#'
 #' @family transformation
 #'
 #' @return The input matrix or matrices with named rows and columns.
 #' @export name_stages
 #'
 #' @examples
-#' matU <- rbind(c(0.0, 0.0, 0.0),
-#'               c(0.3, 0.1, 0.0),
-#'               c(0.0, 0.5, 0.8))
+#' matU <- rbind(
+#'   c(0.0, 0.0, 0.0),
+#'   c(0.3, 0.1, 0.0),
+#'   c(0.0, 0.5, 0.8)
+#' )
 #' # (semi)automated naming
 #' name_stages(matU)
 #' name_stages(matU, prefix = "s")
@@ -33,7 +35,7 @@
 #' # overwrite existing stage names
 #' data(mpm1)
 #' name_stages(mpm1)
-
+#'
 name_stages <- function(mat, names = NULL, prefix = "stage_", left_pad = TRUE) {
   # check argument inputs
   if (!is.matrix(mat) && !is.list(mat)) {
@@ -55,7 +57,7 @@ name_stages <- function(mat, names = NULL, prefix = "stage_", left_pad = TRUE) {
   if (is.null(names) && !is.character(prefix)) {
     stop("Either stage `names` or a naming `prefix` must be supplied.\n")
   }
-  if (!is.null(names) && is.character(prefix)){
+  if (!is.null(names) && is.character(prefix)) {
     warning("Naming `prefix` ignored, using stage `names` instead.\n")
   }
   # construct stage names
@@ -70,12 +72,14 @@ name_stages <- function(mat, names = NULL, prefix = "stage_", left_pad = TRUE) {
     }
   }
   if (mdim != length(names)) {
-    stop("Incorrect number of stage names supplied: ", length(names),
-         " names supplied for ", mdim, " life stages.\n")
+    stop(
+      "Incorrect number of stage names supplied: ", length(names),
+      " names supplied for ", mdim, " life stages.\n"
+    )
   }
   # warn if overwriting existing stage names
   if (is.list(mat) && !is.null(unlist(lapply(mat, dimnames), use.names = FALSE)) |
-      is.matrix(mat) && !is.null(unlist(dimnames(mat), use.names = FALSE))) {
+    is.matrix(mat) && !is.null(unlist(dimnames(mat), use.names = FALSE))) {
     warning("Existing stage names have been overwritten!\n")
   }
   # add stage names to matrix/matrices
