@@ -5,15 +5,15 @@ checkValidMat <- function(M,
                           fail_any_na = TRUE,
                           warn_all_zero = TRUE,
                           warn_surv_issue = FALSE) {
-  
   mn <- deparse(substitute(M)) # name of object passed to M
-  
+
   if (!is.matrix(M) || !is.numeric(M) || (nrow(M) != ncol(M))) {
     stop("Argument ", mn, " must be a square numeric matrix.\n", call. = FALSE)
   }
   if (fail_all_na && all(is.na(M))) {
     stop("Argument ", mn, " contains only missing values (i.e. all <NA>).\n",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
   if (fail_any_na && any(is.na(M))) {
     stop("Argument ", mn, " contains missing values (i.e. <NA>).\n", call. = FALSE)
@@ -23,7 +23,9 @@ checkValidMat <- function(M,
   }
   if (warn_surv_issue && any(colSums(M) > 1)) {
     warning("Argument ", mn, " has at least one stage-specific survival.\n",
-            " probability > 1", call. = FALSE)
+      " probability > 1",
+      call. = FALSE
+    )
   }
 }
 
@@ -31,14 +33,14 @@ checkValidMat <- function(M,
 checkMatchingStageNames <- function(M, N = NULL) {
   if (is.null(N)) {
     if (!identical(rownames(M), colnames(M))) {
-      stop(strwrap(prefix = " ", initial = "","When naming lifestages, both rows and columns 
+      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both rows and columns
                    must be named and their names must be identical.\n"))
     }
   } else {
     if (!identical(rownames(M), colnames(M)) || !identical(rownames(N), colnames(N)) ||
-        !identical(M * 0L, N * 0L)) {
-      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both rows and columns 
-                   must be named their names must be identical, and they must be the same between 
+      !identical(M * 0L, N * 0L)) {
+      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both rows and columns
+                   must be named their names must be identical, and they must be the same between
                    both matrices passed to the function.\n"))
     }
   }
@@ -46,23 +48,24 @@ checkMatchingStageNames <- function(M, N = NULL) {
 
 #' @noRd
 checkValidStartLife <- function(s, M, start_vec = FALSE) {
-  
   if (start_vec) {
     # check that abundances of all stages have been set if passing a population vector
     if ((length(s) > 1 & length(s) != ncol(M)) ||
-        (is.numeric(s) && length(s) == 1 && !(s %in% seq_len(nrow(M)))) ||
-        (is.character(s) && length(s) == 1 && !(s %in% unique(unlist(dimnames(M)))))) {
-      stop(strwrap(prefix = " ", initial = "","Argument 'start' must be an integer within 1:nrow(matU), 
-                   a character matching a stage class name in dimnames(matU), or an integer vector of 
+      (is.numeric(s) && length(s) == 1 && !(s %in% seq_len(nrow(M)))) ||
+      (is.character(s) && length(s) == 1 && !(s %in% unique(unlist(dimnames(M)))))) {
+      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an integer within 1:nrow(matU),
+                   a character matching a stage class name in dimnames(matU), or an integer vector of
                    starting abundances of length ncol(matU).\n"),
-           call. = FALSE)
+        call. = FALSE
+      )
     }
   } else {
     # check that start is a single value, either an index or named life stage
-    if ( length(s) != 1 || !(s %in% seq_len(nrow(M))) && !(s %in% unique(unlist(dimnames(M))))) {
-      stop(strwrap(prefix = " ", initial = "","Argument 'start' must be an integer within 1:nrow(matU), 
+    if (length(s) != 1 || !(s %in% seq_len(nrow(M))) && !(s %in% unique(unlist(dimnames(M))))) {
+      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an integer within 1:nrow(matU),
                    or a character matching a stage class name in dimnames(matU).\n"),
-           call. = FALSE)
+        call. = FALSE
+      )
     }
   }
 }
@@ -73,42 +76,50 @@ checkValidStages <- function(M, stages) {
   arg <- deparse(substitute(stages))
   if (is.logical(stages) && length(stages) != ncol(M)) {
     stop("Length of `", arg, "` (logical vector) must equal the dimension of ",
-         "the matrix (", ncol(M), ").\n", call. = FALSE)
+      "the matrix (", ncol(M), ").\n",
+      call. = FALSE
+    )
   } else if (is.numeric(stages) && !all(stages[!is.na(stages)] %in% 1:ncol(M))) {
     stop("Some stage indices ",
-         ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
-         "exceeded matrix dimension (", nrow(M), "): ",
-         paste(stages[stages > ncol(M) | stages <= 0L], collapse = ", "),
-         call. = FALSE)
+      ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
+      "exceeded matrix dimension (", nrow(M), "): ",
+      paste(stages[stages > ncol(M) | stages <= 0L], collapse = ", "),
+      call. = FALSE
+    )
   } else if (is.character(stages) && any(!stages[!is.na(stages)] %in% colnames(M))) {
     stop("Some stage names ",
-         ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
-         "were not found in matrix: ",
-         paste(stages[!stages %in% colnames(M)], collapse = ", "),
-         call. = FALSE)
+      ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
+      "were not found in matrix: ",
+      paste(stages[!stages %in% colnames(M)], collapse = ", "),
+      call. = FALSE
+    )
   } else if (is.list(stages) && any(sapply(stages, is.numeric)) &&
-             any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% 1:ncol(M))) {
+    any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% 1:ncol(M))) {
     stop("Some stage indices ",
-         ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
-         "exceeded matrix dimension (", nrow(M), "): ",
-         paste(unique(unlist(stages))[!unique(unlist(stages)) %in% 1:ncol(M)],
-               collapse = ", "),
-         call. = FALSE)
+      ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
+      "exceeded matrix dimension (", nrow(M), "): ",
+      paste(unique(unlist(stages))[!unique(unlist(stages)) %in% 1:ncol(M)],
+        collapse = ", "
+      ),
+      call. = FALSE
+    )
   } else if (is.list(stages) && any(sapply(stages, is.character)) &&
-             any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% colnames(M))) {
+    any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% colnames(M))) {
     stop("Some stage names ",
-         ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
-         "were not found in matrix: ",
-         paste(unique(unlist(stages))[!unique(unlist(stages)) %in% colnames(M)],
-         collapse = ", "),
-         call. = FALSE)
+      ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
+      "were not found in matrix: ",
+      paste(unique(unlist(stages))[!unique(unlist(stages)) %in% colnames(M)],
+        collapse = ", "
+      ),
+      call. = FALSE
+    )
   }
 }
 
 #' @noRd
 colSums2 <- function(mat) {
-# like colSums(x, na.rm = TRUE), except that column with only NAs will return NA
-#  rather than 0
+  # like colSums(x, na.rm = TRUE), except that column with only NAs will return NA
+  #  rather than 0
   apply(mat, 2, function(x) {
     ifelse(all(is.na(x)), NA_real_, sum(x, na.rm = TRUE))
   })
@@ -158,11 +169,17 @@ area_under_curve <- function(x, y) {
 
 #' @noRd
 lambda <- function(x) {
-  return(popdemo::eigs(x,what = "lambda"))
+  return(popdemo::eigs(x, what = "lambda"))
 }
 
 
 #' @noRd
 stable.stage <- function(x) {
-  return(popdemo::eigs(x,what = "ss"))
-}
\ No newline at end of file
+  return(popdemo::eigs(x, what = "ss"))
+}
+
+
+#' @noRd
+reproductive.value <- function(x) {
+  return(popdemo::eigs(x, what = "rv"))
+}
